@@ -1,8 +1,6 @@
 #!/bin/sh
 ##
-##    (C) Copyright 2002-2003 Fred Gleason <fredg@paravelsystems.com>
-##
-##      $Id: autogen.sh,v 1.5 2010/07/29 19:32:30 cvs Exp $
+##    (C) Copyright 2002-2003,2016 Fred Gleason <fredg@paravelsystems.com>
 ##
 ##    Adapted from './autogen.sh' in the Jack Audio Connection Kit.
 ##    Copyright (C) 2001-2003 Paul Davis, et al.
@@ -22,6 +20,8 @@
 ##    Boston, MA  02111-1307  USA
 ##
 
+mkdir -p m4
+
 libtoolize=libtoolize
 if which glibtoolize > /dev/null 2>&1; then
       libtoolize=glibtoolize
@@ -37,7 +37,7 @@ aclocal $ACLOCAL_FLAGS || {
     exit 1
 }
 
-automake --add-missing || {
+automake --add-missing -Wno-portability || {
     echo "automake --add-missing failed, exiting..."
     exit 1
 }
