@@ -40,9 +40,11 @@ bool RDReport::ExportMusicSummary(const QDate &startdate,const QDate &enddate,
   QString str;
 
 #ifdef WIN32
-  QString filename=RDDateDecode(exportPath(RDReport::Windows),startdate);
+  QString filename=
+    RDDateDecode(exportPath(RDReport::Windows),startdate,serviceName());
 #else
-  QString filename=RDDateDecode(exportPath(RDReport::Linux),startdate);
+  QString filename=
+    RDDateDecode(exportPath(RDReport::Linux),startdate,serviceName());
 #endif
 
   QFile file(filename);
