@@ -2,9 +2,7 @@
 //
 // Export a Rivendell Technical Report to an ASCII Text File.
 //
-//   (C) Copyright 2002-2006 Fred Gleason <fredg@paravelsystems.com>
-//
-//      $Id: export_technical.cpp,v 1.9.8.1 2012/11/16 18:10:39 cvs Exp $
+//   (C) Copyright 2002-2006,2016 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -46,9 +44,11 @@ bool RDReport::ExportTechnical(const QDate &startdate,const QDate &enddate,
   char eol[3]="\n";
 
 #ifdef WIN32
-  QString filename=RDDateDecode(exportPath(RDReport::Windows),startdate);
+  QString filename=
+    RDDateDecode(exportPath(RDReport::Windows),startdate,serviceName());
 #else
-  QString filename=RDDateDecode(exportPath(RDReport::Linux),startdate);
+  QString filename=
+    RDDateDecode(exportPath(RDReport::Linux),startdate,serviceName());
   if(incl_crs) {
     strcpy(eol,"\r\n");
   }
