@@ -121,7 +121,7 @@
     </message>
     <message>
         <source>ChainTo</source>
-        <translation type="unfinished">ChainTo</translation>
+        <translation type="obsolete">ChainTo</translation>
     </message>
     <message>
         <source>Track</source>
@@ -129,7 +129,7 @@
     </message>
     <message>
         <source>Link</source>
-        <translation type="unfinished">Link</translation>
+        <translation type="obsolete">Link</translation>
     </message>
     <message>
         <source>Traffic</source>
@@ -467,6 +467,50 @@
         <source>NoTime</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>MusicLink</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>TrafficLink</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Chain</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>new cart</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>cart</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Host already exists!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>host already exists</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>service already exists</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>template service</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>does not exist</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>template host</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>RDAddCart</name>
@@ -2092,6 +2136,120 @@ bitte erneut versuchen!</translation>
         <translation type="obsolete">Unbekanntes Audioformat</translation>
     </message>
 </context>
+<context>
+    <name>RDRehash</name>
+    <message>
+        <source>OK</source>
+        <translation type="unfinished">OK</translation>
+    </message>
+    <message>
+        <source>Internal Error</source>
+        <translation type="unfinished">Interner Fehler</translation>
+    </message>
+    <message>
+        <source>Invalid URL</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>RDXport service returned an error</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Invalid user or password</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Audio does not exist</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>RDRenderer</name>
+    <message>
+        <source>no such cart</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>no such cut</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Using temporary file</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Pass 2 of 2</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Writing output file</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Pass 1 of 1</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Pass 1 of 2</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Importing cart</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>first-time event not found</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>last-time event not found</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>STOP</source>
+        <translation type="unfinished">STOP</translation>
+    </message>
+    <message>
+        <source>FAIL</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>NO AUDIO AVAILABLE</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>SKIP</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>--- end of log ---</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>unable to open output file</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>log render halted at line</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>due to STOP</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>at line</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>failed to play (NO AUDIO AVAILABLE)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Rendered log is too long!</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>RDReport</name>
     <message>
