@@ -487,6 +487,30 @@
         <source>cart</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Host already exists!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>host already exists</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>service already exists</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>template service</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>does not exist</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>template host</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>RDAddCart</name>
@@ -2088,6 +2112,93 @@ por favor, tente novamente!</translation>
         <translation type="unfinished"></translation>
     </message>
 </context>
+<context>
+    <name>RDRenderer</name>
+    <message>
+        <source>no such cart</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>no such cut</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Using temporary file</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Pass 2 of 2</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Writing output file</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Pass 1 of 1</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Pass 1 of 2</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Importing cart</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>first-time event not found</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>last-time event not found</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>STOP</source>
+        <translation type="unfinished">PARE</translation>
+    </message>
+    <message>
+        <source>FAIL</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>NO AUDIO AVAILABLE</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>SKIP</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>--- end of log ---</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>unable to open output file</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>log render halted at line</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>due to STOP</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>at line</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>failed to play (NO AUDIO AVAILABLE)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Rendered log is too long!</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>RDReport</name>
     <message>
