@@ -2,9 +2,7 @@
 //
 // Audio card selector widget for Rivendell
 //
-//   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
-//
-//      $Id: rdcardselector.cpp,v 1.15 2007/09/14 14:06:24 fredg Exp $
+//   (C) Copyright 2002-2004,2016 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -38,9 +36,10 @@
 #include <rdcardselector.h>
 
 
-RDCardSelector::RDCardSelector(QWidget *parent,const char *name)
-  : QWidget(parent,name)
+RDCardSelector::RDCardSelector(QWidget *parent)
+  : QWidget(parent)
 {
+  card_id=-1;
   yoffset=0;
 
   //
@@ -82,17 +81,20 @@ RDCardSelector::RDCardSelector(QWidget *parent,const char *name)
   //
   card_port_box=new QSpinBox(this,"card_port_box");
   card_port_box->setGeometry(60,yoffset+22,50,19);
-  card_port_box->setMinValue(0);
+  card_port_box->setSpecialValueText("None");
+  card_port_box->setMinValue(-1);
   card_port_box->setMaxValue(RD_MAX_PORTS-1);
-  card_port_box->setDisabled(true);
+  card_port_box->setValue(-1);
   connect(card_port_box,SIGNAL(valueChanged(int)),this,SLOT(portData(int)));
   card_port_label=new QLabel(card_port_box,tr("Port:"),this,
 				       "card_port_label");
   card_port_label->setGeometry(0,yoffset+24,55,19);
   card_port_label->setAlignment(AlignRight|ShowPrefix);
   for(int i=0;i<RD_MAX_CARDS;i++) {
-    card_max_ports[i]=RD_MAX_PORTS;
+    card_max_ports[i] = 0;
+    cardData(i);
   }
+  card_port_box->setDisabled(true);
 }
 
 
@@ -116,6 +118,24 @@ QSizePolicy RDCardSelector::sizePolicy() const
 }
 
 
+bool RDCardSelector::isDisabled() const
+{
+  return (card_card_box->value()<0)||(card_port_box->value()<0);
+}
+
+
+int RDCardSelector::id() const
+{
+  return card_id;
+}
+
+
+void RDCardSelector::setId(int id)
+{
+  card_id=id;
+}
+
+
 QString RDCardSelector::title() const
 {
   return card_title->text();
@@ -189,25 +209,40 @@ void RDCardSelector::setMaxPorts(int card,int num)
 {
   if(card>=0) {
     card_max_ports[card]=num;
-    card_port_box->setMaxValue(num-1);
+    if (card == this->card()){
+      card_port_box->setMaxValue(num-1);
+      if (num == 0){
+	card_port_box->setValue(-1);
+	card_port_box->setDisabled(true);
+      } else {
+	card_port_box->setDisabled(false);
+      }
+    }
   }
 }
 
-
 void RDCardSelector::cardData(int card)
 {
+  int c;
   if(card>=0) {
-    card_port_box->setEnabled(true);
-    card_port_box->setMaxValue(card_max_ports[card]-1);
+    c = card_max_ports[card]-1;
+    card_port_box->setMaxValue(c);
+    if (c <0){
+      card_port_box->setValue(-1);
+    }
+    card_port_box->setDisabled((c>=0) ? false : true);
   }
   else {
+    card_port_box->setValue(-1);
     card_port_box->setDisabled(true);
   }
   emit cardChanged(card);
+  emit settingsChanged(card_id,card,card_port_box->value());
 }
 
 
 void RDCardSelector::portData(int port)
 {
   emit portChanged(port);
+  emit settingsChanged(card_id,card_card_box->value(),port);
 }
