@@ -166,6 +166,8 @@ class RDCart
 			     const QString &cutname,RDConfig *config);
   static void removePending(RDStation *station,RDUser *user,RDConfig *config);
   static unsigned readXml(std::vector<RDWaveData> *data,const QString &xml);
+  static QString uniqueCartTitle(unsigned cartnum=0);
+  static bool titleIsUnique(unsigned except_cartnum,const QString &str);
   
  private:
   static QVariant GetXmlValue(const QString &tag,const QString &line);
