@@ -49,7 +49,7 @@ RDConfig::RDConfig()
 }
 
 
-RDConfig::RDConfig(QString filename)
+RDConfig::RDConfig(const QString &filename)
 {
   clear();
   conf_filename=filename;
@@ -67,37 +67,62 @@ void RDConfig::setFilename(QString filename)
   conf_filename=filename;
 }
 
+
+QString RDConfig::moduleName() const
+{
+  return conf_module_name;
+}
+
+
+void RDConfig::setModuleName(const QString &modname)
+{
+  conf_module_name=modname;
+}
+
+
+QString RDConfig::userAgent() const
+{
+  return RDConfig::userAgent(conf_module_name);
+}
+
+
 QString RDConfig::audioRoot() const
 {
   return conf_audio_root;
 }
 
+
 QString RDConfig::audioExtension() const
 {
   return conf_audio_extension;
 }
 
+
 QString RDConfig::audioFileName (QString cutname)
 {
   return audioRoot() + QString("/") + cutname + QString(".") +
     audioExtension();
 };
 
+
 QString RDConfig::label() const
 {
   return conf_label;
 }
 
+
 QString RDConfig::audioStoreMountSource() const
 {
   return conf_audio_store_mount_source;
 }
 
+
 QString RDConfig::audioStoreMountType() const
 {
   return conf_audio_store_mount_type;
 }
 
+
 QString RDConfig::audioStoreMountOptions() const
 {
   return conf_audio_store_mount_options;
@@ -224,6 +249,30 @@ void RDConfig::log(const QString &module,LogPriority prio,const QString &msg)
 }
 
 
+bool RDConfig::provisioningCreateHost() const
+{
+  return conf_provisioning_create_host;
+}
+
+
+QString RDConfig::provisioningHostTemplate() const
+{
+  return conf_provisioning_host_template;
+}
+
+
+bool RDConfig::provisioningCreateService() const
+{
+  return conf_provisioning_create_service;
+}
+
+
+QString RDConfig::provisioningServiceTemplate() const
+{
+  return conf_provisioning_service_template;
+}
+
+
 int RDConfig::alsaPeriodQuantity() const
 {
   return conf_alsa_period_quantity;
@@ -308,6 +357,12 @@ bool RDConfig::disableMaintChecks() const
 }
 
 
+bool RDConfig::lockRdairplayMemory() const
+{
+  return conf_lock_rdairplay_memory;
+}
+
+
 unsigned RDConfig::channels() const
 {
   return conf_channels;
@@ -430,6 +485,15 @@ void RDConfig::load()
   conf_audio_store_xport_hostname=
     profile->stringValue("AudioStore","XportHostname","localhost");
 
+  conf_provisioning_create_host=
+    profile->boolValue("Provisioning","CreateHost");
+  conf_provisioning_host_template=
+    profile->stringValue("Provisioning","NewHostTemplate");
+  conf_provisioning_create_service=
+    profile->boolValue("Provisioning","CreateService");
+  conf_provisioning_service_template=
+    profile->stringValue("Provisioning","NewServiceTemplate");
+
   conf_audio_root=
     profile->stringValue("Cae","AudioRoot",RD_AUDIO_ROOT);
   conf_audio_extension=
@@ -474,6 +538,8 @@ void RDConfig::load()
   conf_use_stream_meters=profile->boolValue("Hacks","UseStreamMeters",false);
   conf_disable_maint_checks=
     profile->boolValue("Hacks","DisableMaintChecks",false);
+  conf_lock_rdairplay_memory=
+    profile->boolValue("Hacks","LockRdairplayMemory",false);
   conf_channels=profile->intValue("Format","Channels",RD_DEFAULT_CHANNELS);
 #ifndef WIN32
   if((user=getpwnam(profile->stringValue("Identity","AudioOwner")))!=NULL) {
@@ -515,6 +581,7 @@ void RDConfig::clear()
 #else
   conf_filename=RD_CONF_FILE;
 #endif
+  conf_module_name="";
   conf_mysql_hostname="";
   conf_mysql_username="";
   conf_mysql_dbname="";
@@ -526,6 +593,10 @@ void RDConfig::clear()
   conf_log_core_dump_directory=DEFAULT_LOG_CORE_DUMP_DIRECTORY;
   conf_log_pattern=DEFAULT_LOG_PATTERN;
   conf_log_xload_debug_data=false;
+  conf_provisioning_create_host=false;
+  conf_provisioning_host_template="";
+  conf_provisioning_create_service=false;
+  conf_provisioning_service_template="";
   conf_alsa_period_quantity=RD_ALSA_DEFAULT_PERIOD_QUANTITY;
   conf_alsa_period_size=RD_ALSA_DEFAULT_PERIOD_SIZE;
   conf_alsa_channels_per_pcm=-1;
@@ -548,6 +619,7 @@ void RDConfig::clear()
   conf_jack_ports[1].clear();
   conf_use_stream_meters=false;
   conf_disable_maint_checks=false;
+  conf_lock_rdairplay_memory=false;
   conf_channels=RD_DEFAULT_CHANNELS;
 #ifndef WIN32
   conf_uid=65535;
@@ -564,3 +636,12 @@ void RDConfig::clear()
   conf_sas_tty_device="";
   conf_destinations.clear();
 }
+
+
+QString RDConfig::userAgent(const QString &modname)
+{
+  if(modname.isEmpty()) {
+    return QString("Mozilla/5.0")+" rivendell/"+VERSION;
+  }
+  return QString("Mozilla/5.0 rivendell/")+VERSION+" ("+modname+")";
+}
