@@ -47,9 +47,12 @@ class RDConfig
 
 #endif  // WIN32
   RDConfig();
-  RDConfig(QString filename);
+  RDConfig(const QString &filename);
   QString filename() const;
   void setFilename(QString filename);
+  QString moduleName() const;
+  void setModuleName(const QString &modname);
+  QString userAgent() const;
   QString mysqlHostname() const;
   QString mysqlUsername() const;
   QString mysqlDbname() const;
@@ -62,6 +65,10 @@ class RDConfig
   QString logPattern() const;
   bool logXloadDebugData() const;
   void log(const QString &module,LogPriority prio,const QString &msg);
+  bool provisioningCreateHost() const;
+  QString provisioningHostTemplate() const;
+  bool provisioningCreateService() const;
+  QString provisioningServiceTemplate() const;
   int alsaPeriodQuantity() const;
   int alsaPeriodSize() const;
   int alsaChannelsPerPcm() const;
@@ -85,6 +92,7 @@ class RDConfig
   QString jackPort(int num,int endpt) const;
   bool useStreamMeters() const;
   bool disableMaintChecks() const;
+  bool lockRdairplayMemory() const;
   QString caeLogfile() const;
   bool enableMixerLogging() const;
   unsigned channels() const;
@@ -102,9 +110,11 @@ class RDConfig
   QString destination(unsigned n);
   void load();
   void clear();
+  static QString userAgent(const QString &modname);
 
  private:
   QString conf_filename;
+  QString conf_module_name;
   QString conf_mysql_hostname;
   QString conf_mysql_username;
   QString conf_mysql_dbname;
@@ -115,6 +125,10 @@ class RDConfig
   QString conf_log_directory;
   QString conf_log_core_dump_directory;
   QString conf_log_pattern;
+  bool conf_provisioning_create_host;
+  QString conf_provisioning_host_template;
+  bool conf_provisioning_create_service;
+  QString conf_provisioning_service_template;
   bool conf_log_xload_debug_data;
   int conf_alsa_period_quantity;
   int conf_alsa_period_size;
@@ -136,6 +150,7 @@ class RDConfig
   QString conf_catchd_logname;
   bool conf_use_stream_meters;
   bool conf_disable_maint_checks;
+  bool conf_lock_rdairplay_memory;
   std::vector<QString> conf_jack_ports[2];
   unsigned conf_channels;
 #ifndef WIN32
