@@ -399,6 +399,32 @@ void RDCut::setOriginName(const QString &name) const
 }
 
 
+QString RDCut::originLoginName() const
+{
+  return RDGetSqlValue("CUTS","CUT_NAME",cut_name,"ORIGIN_LOGIN_NAME",cut_db).
+    toString();
+}
+
+
+void RDCut::setOriginLoginName(const QString &name) const
+{
+  SetRow("ORIGIN_LOGIN_NAME",name);
+}
+
+
+QString RDCut::sourceHostname() const
+{
+  return RDGetSqlValue("CUTS","CUT_NAME",cut_name,"SOURCE_HOSTNAME",cut_db).
+    toString();
+}
+
+
+void RDCut::setSourceHostname(const QString &name) const
+{
+  SetRow("SOURCE_HOSTNAME",name);
+}
+
+
 unsigned RDCut::weight() const
 {
   return RDGetSqlValue("CUTS","CUT_NAME",cut_name,"WEIGHT",cut_db).
@@ -1173,7 +1199,10 @@ void RDCut::setMetadata(RDWaveData *data) const
 }
 
 
-bool RDCut::checkInRecording(const QString &stationname,RDSettings *settings,
+bool RDCut::checkInRecording(const QString &station_name,
+			     const QString &user_name,
+			     QString src_hostname,
+			     RDSettings *settings,
 			     unsigned msecs) const
 {
 #ifdef WIN32
@@ -1183,6 +1212,38 @@ bool RDCut::checkInRecording(const QString &stationname,RDSettings *settings,
   RDSqlQuery *q;
   int format;
   QString hash;
+  QHostAddress addr;
+
+  QString user="null";
+  if(!user_name.isEmpty()) {
+    user="\""+RDEscapeString(user_name)+"\"";
+  }
+
+  //
+  // Attempt to resolve IP address
+  //
+  if(addr.setAddress(src_hostname)) {
+    if(addr.isIPv4Address()) {
+      QStringList f0=f0.split(".",addr.toString());
+      if(f0[0]=="127") {
+	src_hostname=station_name;
+      }
+      else {
+	sql=QString("select NAME from STATIONS where ")+
+	  "IPV4_ADDRESS=\""+RDEscapeString(addr.toString())+"\"";
+	q=new RDSqlQuery(sql);
+	if(q->first()) {
+	  src_hostname=q->value(0).toString();
+	}
+      }
+    }
+    if(addr.isIPv6Address()) {
+      QStringList f0=f0.split(":",addr.toString());
+      if(f0.back()=="1") {
+	src_hostname=station_name;
+      }
+    }
+  }
 
   switch(settings->format()) {
   case RDSettings::MpegL2:
@@ -1193,29 +1254,31 @@ bool RDCut::checkInRecording(const QString &stationname,RDSettings *settings,
     format=0;
     break;
   }
-  sql=QString().sprintf("update CUTS set START_POINT=0,END_POINT=%d,\
-                         FADEUP_POINT=-1,FADEDOWN_POINT=-1,\
-                         SEGUE_START_POINT=-1,SEGUE_END_POINT=-1,\
-                         TALK_START_POINT=-1,TALK_END_POINT=-1,\
-                         HOOK_START_POINT=-1,HOOK_END_POINT=-1,\
-                         PLAY_GAIN=0,PLAY_COUNTER=0,LOCAL_COUNTER=0,\
-                         CODING_FORMAT=%d,SAMPLE_RATE=%d,\
-                         BIT_RATE=%d,CHANNELS=%d,LENGTH=%d,\
-                         ORIGIN_DATETIME=\"%s %s\",ORIGIN_NAME=\"%s\",\
-                         UPLOAD_DATETIME=null \
-                         where CUT_NAME=\"%s\"",
-			msecs,
-			format,
-			settings->sampleRate(),
-			settings->bitRate(),
-			settings->channels(),
-			msecs,
-			(const char *)QDate::currentDate().
-			toString("yyyy-MM-dd"),
-			(const char *)QTime::currentTime().
-			toString("hh:mm:ss"),
-			(const char *)stationname,
-			(const char *)cut_name);
+  sql=QString("update CUTS set ")+
+    "START_POINT=0,"+
+    QString().sprintf("END_POINT=%d,",msecs)+
+    "FADEUP_POINT=-1,"+
+    "FADEDOWN_POINT=-1,"+
+    "SEGUE_START_POINT=-1,"+
+    "SEGUE_END_POINT=-1,"+
+    "TALK_START_POINT=-1,"+
+    "TALK_END_POINT=-1,"+
+    "HOOK_START_POINT=-1,"+
+    "HOOK_END_POINT=-1,"+
+    "PLAY_GAIN=0,"+
+    "PLAY_COUNTER=0,"+
+    "LOCAL_COUNTER=0,"+
+    QString().sprintf("CODING_FORMAT=%d,",format)+
+    QString().sprintf("SAMPLE_RATE=%d,",settings->sampleRate())+
+    QString().sprintf("BIT_RATE=%d,",settings->bitRate())+
+    QString().sprintf("CHANNELS=%d,",settings->channels())+
+    QString().sprintf("LENGTH=%d,",msecs)+
+    "ORIGIN_DATETIME=now(),"+
+    "ORIGIN_NAME=\""+RDEscapeString(station_name)+"\","+
+    "ORIGIN_LOGIN_NAME="+user+","+
+    "SOURCE_HOSTNAME=\""+RDEscapeString(src_hostname)+"\","+
+    "UPLOAD_DATETIME=null "+
+    "where CUT_NAME=\""+cut_name+"\"";
   q=new RDSqlQuery(sql);
   delete q;
   return true;
@@ -1464,14 +1527,20 @@ QString RDCut::xml(RDSqlQuery *q,bool absolute,RDSettings *settings)
     xml+="  "+RDXmlField("endDaypart",q->value(47).toTime());
   }
   xml+="  "+RDXmlField("originName",q->value(48).toString());
-  xml+="  "+RDXmlField("weight",q->value(49).toUInt());
-  xml+="  "+RDXmlField("lastPlayDatetime",q->value(50).toDateTime());
-  xml+="  "+RDXmlField("playCounter",q->value(51).toUInt());
+  xml+="  "+RDXmlField("originLoginName",q->value(49).toString());
+  xml+="  "+RDXmlField("sourceHostname",q->value(50).toString());
+  xml+="  "+RDXmlField("weight",q->value(51).toUInt());
+  xml+="  "+RDXmlField("lastPlayDatetime",q->value(52).toDateTime());
+  xml+="  "+RDXmlField("playCounter",q->value(53).toUInt());
   if(settings==NULL) {
-    xml+="  "+RDXmlField("codingFormat",q->value(54).toUInt());
-    xml+="  "+RDXmlField("sampleRate",q->value(55).toUInt());
-    xml+="  "+RDXmlField("bitRate",q->value(56).toUInt());
-    xml+="  "+RDXmlField("channels",q->value(57).toUInt());
+
+
+
+
+    xml+="  "+RDXmlField("codingFormat",q->value(56).toUInt());
+    xml+="  "+RDXmlField("sampleRate",q->value(57).toUInt());
+    xml+="  "+RDXmlField("bitRate",q->value(58).toUInt());
+    xml+="  "+RDXmlField("channels",q->value(59).toUInt());
   }
   else {
     xml+="  "+RDXmlField("codingFormat",(int)settings->format());
@@ -1479,58 +1548,58 @@ QString RDCut::xml(RDSqlQuery *q,bool absolute,RDSettings *settings)
     xml+="  "+RDXmlField("bitRate",settings->bitRate());
     xml+="  "+RDXmlField("channels",settings->channels());
   }
-  xml+="  "+RDXmlField("playGain",q->value(58).toUInt());
+  xml+="  "+RDXmlField("playGain",q->value(60).toUInt());
   if(absolute) {
-    xml+="  "+RDXmlField("startPoint",q->value(59).toInt());
-    xml+="  "+RDXmlField("endPoint",q->value(60).toInt());
-    xml+="  "+RDXmlField("fadeupPoint",q->value(61).toInt());
-    xml+="  "+RDXmlField("fadedownPoint",q->value(62).toInt());
-    xml+="  "+RDXmlField("segueStartPoint",q->value(63).toInt());
-    xml+="  "+RDXmlField("segueEndPoint",q->value(64).toInt());
-    xml+="  "+RDXmlField("segueGain",q->value(65).toInt());
-    xml+="  "+RDXmlField("hookStartPoint",q->value(66).toInt());
-    xml+="  "+RDXmlField("hookEndPoint",q->value(67).toInt());
-    xml+="  "+RDXmlField("talkStartPoint",q->value(68).toInt());
-    xml+="  "+RDXmlField("talkEndPoint",q->value(69).toInt());
+    xml+="  "+RDXmlField("startPoint",q->value(61).toInt());
+    xml+="  "+RDXmlField("endPoint",q->value(62).toInt());
+    xml+="  "+RDXmlField("fadeupPoint",q->value(63).toInt());
+    xml+="  "+RDXmlField("fadedownPoint",q->value(64).toInt());
+    xml+="  "+RDXmlField("segueStartPoint",q->value(65).toInt());
+    xml+="  "+RDXmlField("segueEndPoint",q->value(66).toInt());
+    xml+="  "+RDXmlField("segueGain",q->value(67).toInt());
+    xml+="  "+RDXmlField("hookStartPoint",q->value(68).toInt());
+    xml+="  "+RDXmlField("hookEndPoint",q->value(69).toInt());
+    xml+="  "+RDXmlField("talkStartPoint",q->value(70).toInt());
+    xml+="  "+RDXmlField("talkEndPoint",q->value(71).toInt());
   }
   else {
     xml+="  "+RDXmlField("startPoint",0);
     xml+="  "+
-      RDXmlField("endPoint",q->value(31).toInt()-q->value(59).toInt());
-    if(q->value(61).toInt()<0) {
+      RDXmlField("endPoint",q->value(62).toInt()-q->value(61).toInt());
+    if(q->value(63).toInt()<0) {
       xml+="  "+RDXmlField("fadeupPoint",-1);
     }
     else {
       xml+="  "+
-	RDXmlField("fadeupPoint",q->value(61).toInt()-q->value(59).toInt());
+	RDXmlField("fadeupPoint",q->value(63).toInt()-q->value(61).toInt());
     }
-    if(q->value(62).toInt()<0) {
+    if(q->value(64).toInt()<0) {
       xml+="  "+RDXmlField("fadedownPoint",-1);
     }
     else {
       xml+="  "+
-	RDXmlField("fadedownPoint",q->value(62).toInt()-q->value(59).toInt());
+	RDXmlField("fadedownPoint",q->value(64).toInt()-q->value(61).toInt());
     }
-    if(q->value(63).toInt()<0) {
+    if(q->value(65).toInt()<0) {
       xml+="  "+RDXmlField("segueStartPoint",-1);
       xml+="  "+RDXmlField("segueEndPoint",-1);
     }
     else {
       xml+="  "+RDXmlField("segueStartPoint",
-			   q->value(63).toInt()-q->value(59).toInt());
+			   q->value(65).toInt()-q->value(61).toInt());
       xml+="  "+RDXmlField("segueEndPoint",
-			   q->value(64).toInt()-q->value(59).toInt());
+			   q->value(66).toInt()-q->value(61).toInt());
     }
-    xml+="  "+RDXmlField("segueGain",q->value(65).toInt());
-    if(q->value(66).toInt()<0) {
+    xml+="  "+RDXmlField("segueGain",q->value(67).toInt());
+    if(q->value(68).toInt()<0) {
       xml+="  "+RDXmlField("hookStartPoint",-1);
       xml+="  "+RDXmlField("hookEndPoint",-1);
     }
     else {
       xml+="  "+RDXmlField("hookStartPoint",
-			   q->value(66).toInt()-q->value(59).toInt());
+			   q->value(68).toInt()-q->value(61).toInt());
       xml+="  "+RDXmlField("hookEndPoint",
-			   q->value(67).toInt()-q->value(59).toInt());
+			   q->value(69).toInt()-q->value(61).toInt());
     }
     if(q->value(39).toInt()<0) {
       xml+="  "+RDXmlField("talkStartPoint",-1);
@@ -1538,9 +1607,9 @@ QString RDCut::xml(RDSqlQuery *q,bool absolute,RDSettings *settings)
     }
     else {
       xml+="  "+RDXmlField("talkStartPoint",
-			   q->value(68).toInt()-q->value(59).toInt());
+			   q->value(70).toInt()-q->value(61).toInt());
       xml+="  "+RDXmlField("talkEndPoint",
-			   q->value(69).toInt()-q->value(59).toInt());
+			   q->value(71).toInt()-q->value(61).toInt());
     }
   }
   
