@@ -2,9 +2,7 @@
 //
 // Abstract a Rivendell dropbox configuration.
 //
-//   (C) Copyright 2002-2007 Fred Gleason <fredg@paravelsystems.com>
-//
-//      $Id: rddropbox.cpp,v 1.9.8.1 2013/12/11 20:17:13 cvs Exp $
+//   (C) Copyright 2002-2007,2016 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -25,7 +23,6 @@
 #include <rddropbox.h>
 #include <rdescape_string.h>
 
-
 //
 // Global Classes
 //
@@ -129,6 +126,19 @@ void RDDropbox::setSingleCart(bool state) const
 }
 
 
+bool RDDropbox::forceToMono() const
+{
+  return RDBool(RDGetSqlValue("DROPBOXES","ID",box_id,"FORCE_TO_MONO").
+		toString());
+}
+
+
+void RDDropbox::setForceToMono(bool state) const
+{
+  SetRow("FORCE_TO_MONO",state);
+}
+
+
 unsigned RDDropbox::toCart() const
 {
   return RDGetSqlValue("DROPBOXES","ID",box_id,"TO_CART").toUInt();
