@@ -2,9 +2,7 @@
 //
 // A container class for a list of RML macros.
 //
-//   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
-//
-//      $Id: rdmacro_event.cpp,v 1.22 2011/03/01 20:35:52 cvs Exp $
+//   (C) Copyright 2002-2004,2016 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -26,7 +24,6 @@
 #include <rdmacro_event.h>
 #include <rdstation.h>
 
-
 RDMacroEvent::RDMacroEvent(RDRipc *ripc,QObject *parent,const char *name)
   : QObject(parent,name)
 {
@@ -248,31 +245,36 @@ void RDMacroEvent::exec(int line)
 	if(args.size()==2) {
 	  port=args[1].toUInt();
 	}
-	//stationname=event_cmds[line]->arg(0).toString();
-	sql=
-	  QString().sprintf("select VARVALUE from HOSTVARS \
-                             where (STATION_NAME=\"%s\")&&(NAME=\"%s\")",
-			    (const char *)event_ripc->station(),
-			    (const char *)stationname);
-	q=new RDSqlQuery(sql);
-	if(q->first()) {
-	  stationname=q->value(0).toString();
-	}
-	delete q;
-	station=new RDStation(stationname);
-	if(station->exists()) {
-	  rml.setAddress(station->address());
-	}
-	else {
-	  addr.setAddress(stationname);
-	  if(addr.isNull()) {
-	    emit finished(line);
-	    delete station;
-	    return;
-	  }
+	if(stationname.lower()=="localhost") {
+	  addr.setAddress("127.0.0.2");
 	  rml.setAddress(addr);
 	}
-	delete station;
+	else {
+	  sql=
+	    QString().sprintf("select VARVALUE from HOSTVARS \
+                             where (STATION_NAME=\"%s\")&&(NAME=\"%s\")",
+			      (const char *)event_ripc->station(),
+			      (const char *)stationname);
+	  q=new RDSqlQuery(sql);
+	  if(q->first()) {
+	    stationname=q->value(0).toString();
+	  }
+	  delete q;
+	  station=new RDStation(stationname);
+	  if(station->exists()) {
+	    rml.setAddress(station->address());
+	  }
+	  else {
+	    addr.setAddress(stationname);
+	    if(addr.isNull()) {
+	      emit finished(line);
+	      delete station;
+	      return;
+	    }
+	    rml.setAddress(addr);
+	  }
+	  delete station;
+	}
 	rml.setArgQuantity(event_cmds[line]->argQuantity()-2);
 	cmd=
 	  (RDMacro::Command)(256*event_cmds[line]->arg(1).toString().ascii()[0]+
