@@ -2,9 +2,7 @@
 //
 // Abstract a Rivendell Workstation
 //
-//   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
-//
-//      $Id: rdstation.h,v 1.24.4.7 2014/02/11 23:46:26 cvs Exp $
+//   (C) Copyright 2002-2004,2016 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -133,6 +131,9 @@ class RDStation
   void setCardInputs(int cardnum,int inputs) const;
   int cardOutputs(int cardnum) const;
   void setCardOutputs(int cardnum,int outputs) const;
+  static bool create(const QString &name,QString *err_msg,
+		     const QString &exemplar="");
+  static void remove(const QString &name);
 
  private:
   void SetRow(const QString &param,const QString &value) const;
