@@ -2,9 +2,7 @@
 //
 // The color definitions for RDAirPlay.
 //
-//   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
-//
-//      $Id: colors.h,v 1.37 2012/01/12 16:24:51 cvs Exp $
+//   (C) Copyright 2002-2004,2016 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -20,7 +18,6 @@
 //   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
 
-
 #ifndef COLORS_H
 #define COLORS_H
 
@@ -40,14 +37,6 @@
 #define DISABLED_MODE_TITLE ""
 #define ERROR_MODE_TITLE QObject::tr("ERROR")
 
-//
-// Progress Bars
-//
-#define BAR_UNCHANGED_TRANSITION_COLOR green
-#define BAR_UNCHANGED_STOPPING_COLOR red
-#define BAR_CHANGED_TRANSITION_COLOR yellow
-#define BAR_CHANGED_STOPPING_COLOR blue
-
 //
 // Wall Clock
 //
@@ -69,15 +58,8 @@
 //
 // Full Log Colors
 //
-#define LOG_SCHEDULED_COLOR white
-#define LOG_PLAYING_COLOR green
-#define LOG_PAUSED_COLOR cyan
 #define LOG_NEXT_COLOR "#CCFFCC"
-#define LOG_FINISHED_COLOR gray
 #define LOG_EVERGREEN_COLOR "#008000"
-#define LOG_ERROR_COLOR red
-#define LOG_RELATIVE_TEXT_COLOR black
-#define LOG_HARDTIME_TEXT_COLOR blue
 
 //
 // Pie Counter Color
@@ -111,13 +93,4 @@
 #define POSTPOINT_ONTIME_COLOR green
 #define POSTPOINT_LATE_COLOR red
 
-//
-// Event Editor
-//
-#define EVENT_EDITOR_KNOB_COLOR blue
-#define EVENT_EDITOR_PLAY_MARKER black
-#define EVENT_EDITOR_START_MARKER red
-#define EVENT_EDITOR_BUTTON_FLASH_PERIOD 200
-
-
 #endif  // COLORS_H
