@@ -18,9 +18,11 @@
 //   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
 
+#include <errno.h>
 #include <math.h>
 #include <unistd.h>
 #include <signal.h>
+#include <sys/mman.h>
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <sys/wait.h>
@@ -85,8 +87,8 @@ RDHotkeys *rdhotkeys;
 //
 // Icons
 //
-#include "../icons/rivendell-128x128.xpm"
-#include "../icons/rivendell-22x22.xpm"
+#include "../icons/rdairplay-128x128.xpm"
+#include "../icons/rdairplay-22x22.xpm"
 
 //
 // Prototypes
@@ -129,7 +131,7 @@ MainWidget::MainWidget(QWidget *parent)
   //
   // Splash Screen
   //
-  air_splash_screen=new QSplashScreen(QPixmap(rivendell_128x128_xpm));
+  air_splash_screen=new QSplashScreen(QPixmap(rdairplay_128x128_xpm));
   air_splash_screen->hide();
   QTimer *timer=new QTimer(this);
   connect(timer,SIGNAL(timeout()),this,SLOT(clearSplashData()));
@@ -206,7 +208,7 @@ MainWidget::MainWidget(QWidget *parent)
   //
   // Create And Set Icon
   //
-  air_rivendell_map=new QPixmap(rivendell_xpm);
+  air_rivendell_map=new QPixmap(rdairplay_22x22_xpm);
   setIcon(*air_rivendell_map);
 
   air_start_next=false;
@@ -222,8 +224,10 @@ MainWidget::MainWidget(QWidget *parent)
   //
   // Load Local Configs
   //
-  air_config=new RDConfig();
+  air_config=new RDConfig(RD_CONF_FILE);
   air_config->load();
+  air_config->setModuleName("RDAirPlay");
+
   logfile=air_config->airplayLogname();
 
   str=QString("RDAirPlay")+" v"+VERSION+" - "+tr("Host:");
@@ -909,6 +913,17 @@ MainWidget::MainWidget(QWidget *parent)
   //
   rdripc->connectHost("localhost",RIPCD_TCP_PORT,air_config->password());
 
+  //
+  // (Perhaps) Lock Memory
+  //
+  if(air_config->lockRdairplayMemory()) {
+    if(mlockall(MCL_CURRENT|MCL_FUTURE)<0) {
+      QMessageBox::warning(this,"RDAirPlay - "+tr("Memory Warning"),
+			   tr("Unable to lock all memory")+
+			   " ["+strerror(errno)+"].");
+    }
+  }
+
   LogLine(RDConfig::LogInfo,"RDAirPlay started");
 }
 
