@@ -2,9 +2,7 @@
 //
 // A PodCast Management Utility for Rivendell.
 //
-//   (C) Copyright 2002-2005 Fred Gleason <fredg@paravelsystems.com>
-//
-//      $Id: rdcastmanager.cpp,v 1.11 2008/04/22 19:54:07 grauf Exp $
+//   (C) Copyright 2002-2005,2016 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -27,6 +25,7 @@
 #include <unistd.h>
 #endif
 #include <qapplication.h>
+#include <qwindowsstyle.h>
 #include <qwidget.h>
 #include <qpushbutton.h>
 #include <qlabel.h>
@@ -44,6 +43,7 @@
 #include <rdcmd_switch.h>
 #include <rddb.h>
 #include <rdpodcast.h>
+#include <dbversion.h>
 
 #include <list_casts.h>
 #include <globals.h>
@@ -51,7 +51,7 @@
 //
 // Icons
 //
-#include "../icons/rivendell-22x22.xpm"
+#include "../icons/rdcastmanager-22x22.xpm"
 #include "../icons/greencheckmark.xpm"
 #include "../icons/redx.xpm"
 
@@ -60,28 +60,31 @@
 //
 QString cast_filter;
 QString cast_group;
+QString cast_schedcode;
 RDUser *cast_user;
 RDRipc *cast_ripc;
 RDStation *rdstation_conf;
 RDConfig *config;
+RDSystem *cast_system=NULL;
 
-MainWidget::MainWidget(QWidget *parent,const char *name,WFlags f)
-  :QMainWindow(parent,name,f)
+MainWidget::MainWidget(QWidget *parent)
+  :QMainWindow(parent)
 {
   QString str1;
   QString str2;
-
-  //
-  // HACK: Disable the Broken Custom SuSE Dialogs
-  //
-#ifndef WIN32
-  setenv("QT_NO_KDE_INTEGRATION","1",1);
-#endif  // WIN32
+  bool skip_db_check=false;
+  unsigned schema=0;
 
   //
   // Read Command Options
   //
-  RDCmdSwitch *cmd=new RDCmdSwitch(qApp->argc(),qApp->argv(),"rdcastmanager","\n");
+  RDCmdSwitch *cmd=
+    new RDCmdSwitch(qApp->argc(),qApp->argv(),"rdcastmanager","\n");
+  for(unsigned i=0;i<cmd->keys();i++) {
+    if(cmd->key(i)=="--skip-db-check") {
+      skip_db_check=true;
+    }
+  }
   delete cmd;
 
   //
@@ -93,9 +96,11 @@ MainWidget::MainWidget(QWidget *parent,const char *name,WFlags f)
   //
   // Load Local Configs
   //
-  config=new RDConfig();
+  config=new RDConfig(RD_CONF_FILE);
   config->load();
-  str1=QString(tr("RDCastManager - Host"));
+  config->setModuleName("RDCastManager");
+
+  str1=QString("RDCastManager")+" v"+VERSION+" - "+tr("Host");
   str2=QString(tr("User: [Unknown]"));
   setCaption(QString().sprintf("%s: %s, %s",(const char *)str1,
 			       (const char *)config->stationName(),
@@ -105,11 +110,17 @@ MainWidget::MainWidget(QWidget *parent,const char *name,WFlags f)
   // Open Database
   //
   QString err;
-  QSqlDatabase *db=RDInitDb (&err);
+  QSqlDatabase *db=RDInitDb(&schema,&err);
   if(!db) {
     QMessageBox::warning(this,tr("Can't Connect"),err);
     exit(0);
   }
+  if((schema!=RD_VERSION_DATABASE)&&(!skip_db_check)) {
+    fprintf(stderr,
+	    "rdcastmanager: database version mismatch, should be %u, is %u\n",
+	    RD_VERSION_DATABASE,schema);
+    exit(256);
+  }
 
   //
   // RIPC Connection
@@ -126,6 +137,7 @@ MainWidget::MainWidget(QWidget *parent,const char *name,WFlags f)
   // Station Configuration
   //
   rdstation_conf=new RDStation(config->stationName(),this);
+  cast_system=new RDSystem();
 
   //
   // User
@@ -148,7 +160,7 @@ MainWidget::MainWidget(QWidget *parent,const char *name,WFlags f)
   //
   // Create Icons
   //
-  cast_rivendell_map=new QPixmap(rivendell_xpm);
+  cast_rivendell_map=new QPixmap(rdcastmanager_22x22_xpm);
   setIcon(*cast_rivendell_map);
   cast_greencheckmark_map=new QPixmap(greencheckmark_xpm);
   cast_redx_map=new QPixmap(redx_xpm);
@@ -156,7 +168,7 @@ MainWidget::MainWidget(QWidget *parent,const char *name,WFlags f)
   //
   // Feed List
   //
-  cast_feed_list=new RDListView(this,"cast_feed_list");
+  cast_feed_list=new RDListView(this);
   cast_feed_list->setFont(default_font);
   cast_feed_list->setAllColumnsShowFocus(true);
   cast_feed_list->setItemMargin(5);
@@ -178,7 +190,7 @@ MainWidget::MainWidget(QWidget *parent,const char *name,WFlags f)
   //
   // Open Button
   //
-  cast_open_button=new QPushButton(this,"cast_open_button");
+  cast_open_button=new QPushButton(this);
   cast_open_button->setFont(button_font);
   cast_open_button->setText(tr("&View\nFeed"));
   connect(cast_open_button,SIGNAL(clicked()),this,SLOT(openData()));
@@ -186,7 +198,7 @@ MainWidget::MainWidget(QWidget *parent,const char *name,WFlags f)
   //
   // Close Button
   //
-  cast_close_button=new QPushButton(this,"cast_close_button");
+  cast_close_button=new QPushButton(this);
   cast_close_button->setFont(button_font);
   cast_close_button->setText(tr("&Close"));
   connect(cast_close_button,SIGNAL(clicked()),this,SLOT(quitMainWidget()));
@@ -213,7 +225,7 @@ void MainWidget::userChangedData()
   if(cast_user!=NULL) {
     delete cast_user;
   }
-  str1=QString(tr("RDCastManager - Host"));
+  str1=QString("RDCastManager")+" v"+VERSION+" - "+tr("Host");
   str2=QString(tr("User"));
   setCaption(QString().sprintf("%s: %s, %s: %s",(const char *)str1,
 			       (const char *)config->stationName(),
@@ -383,7 +395,7 @@ int main(int argc,char *argv[])
   //
   // Start Event Loop
   //
-  MainWidget *w=new MainWidget(NULL,"main",0);
+  MainWidget *w=new MainWidget();
   a.setMainWidget(w);
   w->setGeometry(w->geometry().x(),w->geometry().y(),w->sizeHint().width(),w->sizeHint().height());
   w->show();
