@@ -2,7 +2,7 @@
 //
 // The Event Schedule Manager for Rivendell.
 //
-//   (C) Copyright 2002-2015 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2002-2017 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -19,7 +19,6 @@
 //
 
 #include <unistd.h>
-#include <vector>
 
 #include <qapplication.h>
 #include <qwindowsstyle.h>
@@ -92,11 +91,31 @@ RDSystem *catch_system=NULL;
 #include "../icons/switch3.xpm"
 #include "../icons/download.xpm"
 #include "../icons/upload.xpm"
-#include "../icons/rivendell-22x22.xpm"
+#include "../icons/rdcatch-22x22.xpm"
+
+CatchConnector::CatchConnector(RDCatchConnect *conn,const QString &station_name)
+{
+  catch_connect=conn;
+  catch_station_name=station_name;
+}
 
 
-MainWidget::MainWidget(QWidget *parent,const char *name)
-  :QWidget(parent,name)
+RDCatchConnect *CatchConnector::connector() const
+{
+  return catch_connect;
+}
+
+
+QString CatchConnector::stationName()
+{
+  return catch_station_name;
+}
+
+
+
+
+MainWidget::MainWidget(QWidget *parent)
+  :QWidget(parent)
 {
   QString str;
   catch_host_warnings=false;
@@ -151,7 +170,7 @@ MainWidget::MainWidget(QWidget *parent,const char *name)
   catch_switch_map=new QPixmap(switch3_xpm);
   catch_download_map=new QPixmap(download_xpm);
   catch_upload_map=new QPixmap(upload_xpm);
-  catch_rivendell_map=new QPixmap(rivendell_xpm);
+  catch_rivendell_map=new QPixmap(rdcatch_22x22_xpm);
   setIcon(*catch_rivendell_map);
 
 
@@ -183,6 +202,7 @@ MainWidget::MainWidget(QWidget *parent,const char *name)
   //
   catch_config=new RDConfig();
   catch_config->load();
+  catch_config->setModuleName("RDCatch");
 
   str=QString("RDCatch")+" v"+VERSION+" - "+tr("Host")+":";
   setCaption(QString().sprintf("%s %s",(const char *)str,
@@ -241,7 +261,7 @@ MainWidget::MainWidget(QWidget *parent,const char *name)
   //
   // CAE Connection
   //
-  catch_cae=new RDCae(rdstation_conf,catch_config,this,"catch_cae");
+  catch_cae=new RDCae(rdstation_conf,catch_config,this);
   connect(catch_cae,SIGNAL(isConnected(bool)),this,SLOT(initData(bool)));
   connect(catch_cae,SIGNAL(playing(int)),this,SLOT(playedData(int)));
   connect(catch_cae,SIGNAL(playStopped(int)),
@@ -256,70 +276,64 @@ MainWidget::MainWidget(QWidget *parent,const char *name)
   //
   // Deck Monitors
   //
-  catch_monitor_view=new QScrollView(this,"catch_monitor_view",
-				     Qt::WNoAutoErase);
+  catch_monitor_view=new QScrollView(this,"",Qt::WNoAutoErase);
   catch_monitor_vbox=new VBox(catch_monitor_view);
   catch_monitor_vbox->setSpacing(2);
   catch_monitor_view->addChild(catch_monitor_vbox);
 
-  QSignalMapper *mapper=new QSignalMapper(this,"deck_mapper");
+  QSignalMapper *mapper=new QSignalMapper(this);
   connect(mapper,SIGNAL(mapped(int)),this,SLOT(abortData(int)));
-  QSignalMapper *mon_mapper=new QSignalMapper(this,"monitor_mapper");
+  QSignalMapper *mon_mapper=new QSignalMapper(this);
   connect(mon_mapper,SIGNAL(mapped(int)),this,SLOT(monitorData(int)));
   QString sql;
   RDSqlQuery *q1;
   RDSqlQuery *q=
     new RDSqlQuery("select NAME,IPV4_ADDRESS from STATIONS\
                    where NAME!=\"DEFAULT\"");
-  catch_station_count=0;
   while(q->next()) {
-    catch_connect[catch_station_count].connect=
-      new RDCatchConnect(catch_station_count,this,"catch_connect");
-    catch_connect[catch_station_count].station=
-      q->value(0).toString().lower();
-    connect(catch_connect[catch_station_count].connect,
+    catch_connect.push_back(new CatchConnector(new RDCatchConnect(catch_connect.size(),this),q->value(0).toString().lower()));
+    connect(catch_connect.back()->connector(),
       SIGNAL(statusChanged(int,unsigned,RDDeck::Status,int,const QString &)),
       this,
       SLOT(statusChangedData(int,unsigned,RDDeck::Status,int,const QString &)));
-    connect(catch_connect[catch_station_count].connect,
+    connect(catch_connect.back()->connector(),
 	    SIGNAL(monitorChanged(int,unsigned,bool)),
 	    this,SLOT(monitorChangedData(int,unsigned,bool)));
-    connect(catch_connect[catch_station_count].connect,
+    connect(catch_connect.back()->connector(),
 	    SIGNAL(connected(int,bool)),
 	    this,SLOT(connectedData(int,bool)));
-    connect(catch_connect[catch_station_count].connect,
+    connect(catch_connect.back()->connector(),
 	    SIGNAL(meterLevel(int,int,int,int)),
 	    this,SLOT(meterLevelData(int,int,int,int)));
-    connect(catch_connect[catch_station_count].connect,
+    connect(catch_connect.back()->connector(),
 	    SIGNAL(eventUpdated(int)),
 	    this,SLOT(eventUpdatedData(int)));
-    connect(catch_connect[catch_station_count].connect,
+    connect(catch_connect.back()->connector(),
 	    SIGNAL(eventPurged(int)),
 	    this,SLOT(eventPurgedData(int)));
-    connect(catch_connect[catch_station_count].connect,
+    connect(catch_connect.back()->connector(),
+	    SIGNAL(deckEventSent(int,int,int)),
+	    this,SLOT(deckEventSentData(int,int,int)));
+    connect(catch_connect.back()->connector(),
 	    SIGNAL(heartbeatFailed(int)),
 	    this,SLOT(heartbeatFailedData(int)));
-    catch_connect[catch_station_count].connect->
+    catch_connect.back()->connector()->
       connectHost(q->value(1).toString(),RDCATCHD_TCP_PORT,
 		  catch_config->password());
-    catch_station_count++;
-
     sql=QString().sprintf("select CHANNEL,MON_PORT_NUMBER from DECKS \
 where (CARD_NUMBER!=-1)&&(PORT_NUMBER!=-1)&&(CHANNEL>0)&&(STATION_NAME=\"%s\") \
 order by CHANNEL",(const char *)q->value(0).toString().lower());
     q1=new RDSqlQuery(sql);
     while(q1->next()) {
-      catch_connect[catch_station_count-1].
-	chan.push_back(q1->value(0).toUInt());
-      catch_connect[catch_station_count-1].
-	mon_id.push_back(catch_monitor.size());
+      catch_connect.back()->chan.push_back(q1->value(0).toUInt());
+      catch_connect.back()->mon_id.push_back(catch_monitor.size());
 
 
       catch_monitor.push_back(new CatchMonitor());
       catch_monitor.back()->setDeckMon(new DeckMon(q->value(0).toString(),
 						   q1->value(0).toUInt(),
 						   catch_monitor_vbox));
-      catch_monitor.back()->setSerialNumber(catch_station_count-1);
+      catch_monitor.back()->setSerialNumber(catch_connect.size()-1);
       catch_monitor.back()->setChannelNumber(q1->value(0).toUInt());
       catch_monitor_vbox->addWidget(catch_monitor.back()->deckMon());
 
@@ -360,18 +374,16 @@ order by CHANNEL",(const char *)q->value(0).toString().lower());
   catch_show_active_label->setAlignment(AlignLeft|AlignVCenter);
   connect(catch_show_active_box,SIGNAL(toggled(bool)),
 	  this,SLOT(filterChangedData(bool)));
-  catch_show_today_box=new QCheckBox(this,"catch_show_today_box");
-  catch_show_today_label=new QLabel(catch_show_active_box,
-				     tr("Show Only Today's Events"),
-				     this,"catch_show_today_label");
+  catch_show_today_box=new QCheckBox(this);
+  catch_show_today_label=
+    new QLabel(catch_show_active_box,tr("Show Only Today's Events"),this);
   catch_show_today_label->setFont(label_font);
   catch_show_today_label->setAlignment(AlignLeft|AlignVCenter);
   connect(catch_show_today_box,SIGNAL(toggled(bool)),
 	  this,SLOT(filterChangedData(bool)));
 
-  catch_dow_box=new QComboBox(this,"catch_down_box");
-  catch_dow_label=new QLabel(catch_dow_box,tr("Show DayOfWeek:"),
-				     this,"catch_dow_label");
+  catch_dow_box=new QComboBox(this);
+  catch_dow_label=new QLabel(catch_dow_box,tr("Show DayOfWeek:"),this);
   catch_dow_label->setFont(label_font);
   catch_dow_label->setAlignment(AlignRight|AlignVCenter);
   catch_dow_box->insertItem(tr("All"));
@@ -396,7 +408,7 @@ order by CHANNEL",(const char *)q->value(0).toString().lower());
   //
   // Cart List
   //
-  catch_recordings_list=new CatchListView(this,"catch_recordings_list");
+  catch_recordings_list=new CatchListView(this);
   catch_recordings_list->setAllColumnsShowFocus(true);
   catch_recordings_list->setItemMargin(5);
   catch_recordings_list->setFont(list_font);
@@ -478,7 +490,7 @@ order by CHANNEL",(const char *)q->value(0).toString().lower());
   //
   // Add Button
   //
-  catch_add_button=new QPushButton(this,"add_button");
+  catch_add_button=new QPushButton(this);
   catch_add_button->setFont(button_font);
   catch_add_button->setText(tr("&Add"));
   connect(catch_add_button,SIGNAL(clicked()),this,SLOT(addData()));
@@ -486,7 +498,7 @@ order by CHANNEL",(const char *)q->value(0).toString().lower());
   //
   // Edit Button
   //
-  catch_edit_button=new QPushButton(this,"edit_button");
+  catch_edit_button=new QPushButton(this);
   catch_edit_button->setFont(button_font);
   catch_edit_button->setText(tr("&Edit"));
   connect(catch_edit_button,SIGNAL(clicked()),this,SLOT(editData()));
@@ -494,7 +506,7 @@ order by CHANNEL",(const char *)q->value(0).toString().lower());
   //
   // Delete Button
   //
-  catch_delete_button=new QPushButton(this,"delete_button");
+  catch_delete_button=new QPushButton(this);
   catch_delete_button->setFont(button_font);
   catch_delete_button->setText(tr("&Delete"));
   connect(catch_delete_button,SIGNAL(clicked()),this,SLOT(deleteData()));
@@ -502,7 +514,7 @@ order by CHANNEL",(const char *)q->value(0).toString().lower());
   //
   // Scroll Button
   //
-  catch_scroll_button=new QPushButton(this,"catch_scroll_button");
+  catch_scroll_button=new QPushButton(this);
   catch_scroll_button->setFont(button_font);
   catch_scroll_button->setText(tr("Scroll"));
   connect(catch_scroll_button,SIGNAL(clicked()),this,SLOT(scrollButtonData()));
@@ -510,7 +522,7 @@ order by CHANNEL",(const char *)q->value(0).toString().lower());
   //
   // Reports Button
   //
-  catch_reports_button=new QPushButton(this,"catch_reports_button");
+  catch_reports_button=new QPushButton(this);
   catch_reports_button->setFont(button_font);
   catch_reports_button->setText(tr("Reports"));
   connect(catch_reports_button,SIGNAL(clicked()),this,SLOT(reportsButtonData()));
@@ -518,34 +530,31 @@ order by CHANNEL",(const char *)q->value(0).toString().lower());
   //
   // Wall Clock
   //
-  catch_clock_label=new QLabel("00:00:00",this,"catch_clock_label");
+  catch_clock_label=new QLabel("00:00:00",this);
   catch_clock_label->setFont(clock_font);
   catch_clock_label->setAlignment(AlignCenter);
-  catch_clock_timer=new QTimer(this,"catch_clock_timer");
+  catch_clock_timer=new QTimer(this);
   connect(catch_clock_timer,SIGNAL(timeout()),this,SLOT(clockData()));
   clockData();
 
   //
   // Play Head Button
   //
-  catch_head_button=
-    new RDTransportButton(RDTransportButton::PlayFrom,this,"catch_head_button");
+  catch_head_button=new RDTransportButton(RDTransportButton::PlayFrom,this);
   catch_head_button->setDisabled(true);
   connect(catch_head_button,SIGNAL(clicked()),this,SLOT(headButtonData()));
 
   //
   // Play Tail Button
   //
-  catch_tail_button=
-    new RDTransportButton(RDTransportButton::PlayTo,this,"catch_tail_button");
+  catch_tail_button=new RDTransportButton(RDTransportButton::PlayTo,this);
   catch_tail_button->setDisabled(true);
   connect(catch_tail_button,SIGNAL(clicked()),this,SLOT(tailButtonData()));
 
   //
   // Play Stop Button
   //
-  catch_stop_button=
-    new RDTransportButton(RDTransportButton::Stop,this,"catch_stop_button");
+  catch_stop_button=new RDTransportButton(RDTransportButton::Stop,this);
   catch_stop_button->setDisabled(true);
   catch_stop_button->setOnColor(red);
   connect(catch_stop_button,SIGNAL(clicked()),this,SLOT(stopButtonData()));
@@ -554,7 +563,7 @@ order by CHANNEL",(const char *)q->value(0).toString().lower());
   //
   // Close Button
   //
-  catch_close_button=new QPushButton(this,"close_button");
+  catch_close_button=new QPushButton(this);
   catch_close_button->setFont(button_font);
   catch_close_button->setText(tr("&Close"));
   catch_close_button->setFocus();
@@ -564,13 +573,13 @@ order by CHANNEL",(const char *)q->value(0).toString().lower());
   //
   // Next Event Timer
   //
-  catch_next_timer=new QTimer(this,"catch_next_timer");
+  catch_next_timer=new QTimer(this);
   connect(catch_next_timer,SIGNAL(timeout()),this,SLOT(nextEventData()));
 
   //
   // Midnight Timer
   //
-  catch_midnight_timer=new QTimer(this,"catch_midnight_timer");
+  catch_midnight_timer=new QTimer(this);
   connect(catch_midnight_timer,SIGNAL(timeout()),this,SLOT(midnightData()));
   midnightData();
   LoadGeometry();
@@ -589,7 +598,7 @@ order by CHANNEL",(const char *)q->value(0).toString().lower());
   // Silly Resize Workaround
   // (so that the deck monitors get laid out properly)
   //
-  QTimer *timer=new QTimer(this,"resize_timer");
+  QTimer *timer=new QTimer(this);
   connect(timer,SIGNAL(timeout()),this,SLOT(resizeData()));
   timer->start(1,true);
 }
@@ -625,7 +634,7 @@ void MainWidget::resizeData()
 void MainWidget::connectedData(int serial,bool state)
 {
   if(state) {
-    catch_connect[serial].connect->enableMetering(true);
+    catch_connect[serial]->connector()->enableMetering(true);
   }
 }
 
@@ -710,7 +719,7 @@ void MainWidget::addData()
 	}
 	catch_recordings_list->setSelected(item,true);
 	catch_recordings_list->ensureItemVisible(item);
-	catch_connect[conn].connect->addEvent(n);
+	catch_connect[conn]->connector()->addEvent(n);
 	nextEventData();
 	break;
 
@@ -774,15 +783,15 @@ void MainWidget::editData()
 	    fprintf(stderr,"rdcatch: invalid connection index!\n");
 	    return;
 	  }
-	  catch_connect[old_conn].connect->removeEvent(id);
-	  catch_connect[new_conn].connect->addEvent(id);
+	  catch_connect[old_conn]->connector()->removeEvent(id);
+	  catch_connect[new_conn]->connector()->addEvent(id);
 	  nextEventData();
 	}
 	delete recording;
 	break;
 
       case RDRecording::Playout:
-	playout=new EditPlayout(id,&new_events,&catch_filter,this,"playout");
+	playout=new EditPlayout(id,&new_events,&catch_filter,this);
 	if(playout->exec()>=0) {
 	  RefreshLine(item);
 	  new_conn=GetConnection(item->text(24));
@@ -790,15 +799,15 @@ void MainWidget::editData()
 	    fprintf(stderr,"rdcatch: invalid connection index!\n");
 	    return;
 	  }
-	  catch_connect[old_conn].connect->removeEvent(id);
-	  catch_connect[new_conn].connect->addEvent(id);
+	  catch_connect[old_conn]->connector()->removeEvent(id);
+	  catch_connect[new_conn]->connector()->addEvent(id);
 	  nextEventData();
 	}
 	delete playout;
 	break;
 
       case RDRecording::MacroEvent:
-	event=new EditCartEvent(id,&new_events,this,"recording");
+	event=new EditCartEvent(id,&new_events,this);
 	if(event->exec()>=0) {
 	  RefreshLine(item);
 	  new_conn=GetConnection(item->text(24));
@@ -806,15 +815,15 @@ void MainWidget::editData()
 	    fprintf(stderr,"rdcatch: invalid connection index!\n");
 	    return;
 	  }
-	  catch_connect[old_conn].connect->removeEvent(id);
-	  catch_connect[new_conn].connect->addEvent(id);
+	  catch_connect[old_conn]->connector()->removeEvent(id);
+	  catch_connect[new_conn]->connector()->addEvent(id);
 	  nextEventData();
 	}
 	delete event;
 	break;
 
       case RDRecording::SwitchEvent:
-	switch_event=new EditSwitchEvent(id,&new_events,this,"recording");
+	switch_event=new EditSwitchEvent(id,&new_events,this);
 	if(switch_event->exec()>=0) {
 	  RefreshLine(item);
 	  new_conn=GetConnection(item->text(24));
@@ -822,15 +831,15 @@ void MainWidget::editData()
 	    fprintf(stderr,"rdcatch: invalid connection index!\n");
 	    return;
 	  }
-	  catch_connect[old_conn].connect->removeEvent(id);
-	  catch_connect[new_conn].connect->addEvent(id);
+	  catch_connect[old_conn]->connector()->removeEvent(id);
+	  catch_connect[new_conn]->connector()->addEvent(id);
 	  nextEventData();
 	}
 	delete switch_event;
 	break;
 
       case RDRecording::Download:
-	download=new EditDownload(id,&new_events,&catch_filter,this,"playout");
+	download=new EditDownload(id,&new_events,&catch_filter,this);
 	if(download->exec()>=0) {
 	  RefreshLine(item);
 	  new_conn=GetConnection(item->text(24));
@@ -838,15 +847,15 @@ void MainWidget::editData()
 	    fprintf(stderr,"rdcatch: invalid connection index!\n");
 	    return;
 	  }
-	  catch_connect[old_conn].connect->removeEvent(id);
-	  catch_connect[new_conn].connect->addEvent(id);
+	  catch_connect[old_conn]->connector()->removeEvent(id);
+	  catch_connect[new_conn]->connector()->addEvent(id);
 	  nextEventData();
 	}
 	delete download;
 	break;
 
       case RDRecording::Upload:
-	upload=new EditUpload(id,&new_events,&catch_filter,this,"playout");
+	upload=new EditUpload(id,&new_events,&catch_filter,this);
 	if(upload->exec()>=0) {
 	  RefreshLine(item);
 	  new_conn=GetConnection(item->text(24));
@@ -854,8 +863,8 @@ void MainWidget::editData()
 	    fprintf(stderr,"rdcatch: invalid connection index!\n");
 	    return;
 	  }
-	  catch_connect[old_conn].connect->removeEvent(id);
-	  catch_connect[new_conn].connect->addEvent(id);
+	  catch_connect[old_conn]->connector()->removeEvent(id);
+	  catch_connect[new_conn]->connector()->addEvent(id);
 	  nextEventData();
 	}
 	delete upload;
@@ -900,7 +909,7 @@ void MainWidget::deleteData()
     fprintf(stderr,"rdcatch: invalid connection index!\n");
     return;
   }
-  catch_connect[conn].connect->removeEvent(item->text(28).toInt());
+  catch_connect[conn]->connector()->removeEvent(item->text(28).toInt());
   sql=QString().sprintf("delete from RECORDINGS where ID=%s",
 			(const char *)item->text(28));
   q=new RDSqlQuery(sql);
@@ -1040,6 +1049,15 @@ void MainWidget::monitorChangedData(int serial,unsigned chan,bool state)
 }
 
 
+void MainWidget::deckEventSentData(int serial,int chan,int number)
+{
+  int mon=GetMonitor(serial,chan);
+  if(mon>=0) {
+    catch_monitor[mon]->deckMon()->setEvent(number);
+  }
+}
+
+
 void MainWidget::scrollButtonData()
 {
   EnableScroll(!catch_scroll);
@@ -1164,9 +1182,9 @@ void MainWidget::meterLevelData(int serial,int deck,int l_r,int level)
 {
   DeckMon *monitor;
 
-  for(unsigned i=0;i<catch_connect[serial].chan.size();i++) {
-    if(catch_connect[serial].chan[i]==(unsigned)deck) {
-       monitor=catch_monitor[catch_connect[serial].mon_id[i]]->deckMon();
+  for(unsigned i=0;i<catch_connect[serial]->chan.size();i++) {
+    if(catch_connect[serial]->chan[i]==(unsigned)deck) {
+       monitor=catch_monitor[catch_connect[serial]->mon_id[i]]->deckMon();
        if(l_r==0) {
 	 monitor->setLeftMeter(level);
        }
@@ -1181,14 +1199,14 @@ void MainWidget::meterLevelData(int serial,int deck,int l_r,int level)
 
 void MainWidget::abortData(int id)
 {
-  catch_connect[catch_monitor[id]->serialNumber()].connect->
+  catch_connect[catch_monitor[id]->serialNumber()]->connector()->
     stop(catch_monitor[id]->channelNumber());
 }
 
 
 void MainWidget::monitorData(int id)
 {
-  catch_connect[catch_monitor[id]->serialNumber()].connect->
+  catch_connect[catch_monitor[id]->serialNumber()]->connector()->
     toggleMonitor(catch_monitor[id]->channelNumber());
 }
 
@@ -1258,7 +1276,7 @@ void MainWidget::heartbeatFailedData(int id)
 
   str=QString(tr("Control connection timed out to host"));
   QString msg=QString().sprintf("%s '%s'!",(const char *)str,
-			       (const char *)catch_connect[id].station);
+				(const char *)catch_connect[id]->stationName());
   QMessageBox::warning(this,"RDCatch",msg);
 }
 
@@ -1588,7 +1606,7 @@ void MainWidget::ProcessNewRecords(std::vector<int> *adds)
       fprintf(stderr,"rdcatch: invalid connection index!\n");
       return;
     }
-    catch_connect[conn].connect->addEvent(adds->at(i));
+    catch_connect[conn]->connector()->addEvent(adds->at(i));
   }
   nextEventData();
 }
@@ -2529,14 +2547,13 @@ int MainWidget::GetMonitor(int serial,int chan)
 
 int MainWidget::GetConnection(QString station,unsigned chan)
 {
-  for(int i=0;i<catch_station_count;i++) {
-    if(catch_connect[i].station==station.lower()) {
+  for(unsigned i=0;i<catch_connect.size();i++) {
+    if(catch_connect[i]->stationName()==station.lower()) {
       if(chan==0) {
 	return i;
       }
-      for(unsigned j=0;j<catch_connect[i].chan.size();j++) {
-    printf("J: %u\n",j);
-	if(catch_connect[i].chan[j]==chan) {
+      for(unsigned j=0;j<catch_connect[i]->chan.size();j++) {
+	if(catch_connect[i]->chan[j]==chan) {
 	  return i;
 	}
       }
@@ -2619,7 +2636,7 @@ int main(int argc,char *argv[])
   //
   // Start Event Loop
   //
-  MainWidget *w=new MainWidget(NULL,"main");
+  MainWidget *w=new MainWidget();
   a.setMainWidget(w);
   w->show();
   return a.exec();
