@@ -202,6 +202,14 @@ Do you still want to delete?</source>
         <source>ORD</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>SHA1</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>not available</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>CdRipper</name>
@@ -1173,10 +1181,6 @@ Do you still want to delete it?</source>
         <source>&amp;Outcue</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Origin</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>ISRC</source>
         <translation type="unfinished"></translation>
@@ -1392,5 +1396,17 @@ Do you still want to save?</source>
         <source>Order</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>unknown</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Ingest</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Source</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 </TS>
