@@ -1330,7 +1330,7 @@ Vil du sletta ho likevel?</translation>
     </message>
     <message>
         <source>Origin</source>
-        <translation>Opphav</translation>
+        <translation type="obsolete">Opphav</translation>
     </message>
     <message>
         <source>ISRC</source>
@@ -1554,5 +1554,17 @@ Vil du lagra likevel?</translation>
         <source>Order</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>unknown</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Ingest</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Source</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 </TS>
