@@ -1332,7 +1332,7 @@ Você ainda quer deletá-lo?</translation>
     </message>
     <message>
         <source>Origin</source>
-        <translation>Origem</translation>
+        <translation type="obsolete">Origem</translation>
     </message>
     <message>
         <source>ISRC</source>
@@ -1556,5 +1556,17 @@ Você ainda quer salvar?</translation>
         <source>Order</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>unknown</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Ingest</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Source</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 </TS>
