@@ -234,7 +234,7 @@ einfügen</translation>
     <message>
         <source>Save
 &amp;As</source>
-        <translation>Speichern
+        <translation type="obsolete">Speichern
 &amp;Als</translation>
     </message>
     <message>
@@ -401,6 +401,26 @@ die für den gewählten Service ungültig sind!</translation>
         <source>EXT DATA</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Link Start</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Len</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Save</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>As</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Render</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>EditLogLine</name>
