@@ -256,7 +256,7 @@ Meta
     <message>
         <source>Save
 &amp;As</source>
-        <translation>&amp;Salvar
+        <translation type="obsolete">&amp;Salvar
 Como</translation>
     </message>
     <message>
@@ -403,6 +403,26 @@ para o serviço selecionado!</translation>
         <source>EXT DATA</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Link Start</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Len</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Save</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>As</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Render</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>EditLogLine</name>
