@@ -377,10 +377,11 @@ void EditClock::deleteData()
   if(item->text(4).isEmpty()) {
     return;
   }
-  str=QString(tr("Are you sure you want to\ndelete"));
+  str=QString(tr("Are you sure you want to delete\n"));
   if(QMessageBox::question(this,tr("Delete Event"),
-			   QString().sprintf("%s \'%s\'?",(const char *)str,
-			 (const char *)item->text(3)),
+			   QString().sprintf("%s \'(%s) %s\'?",(const char *)str,
+			 (const char *)item->text(0),
+			 (const char *)item->text(2)),
 			  QMessageBox::Yes,QMessageBox::No)!=
      QMessageBox::Yes) {
     return;
@@ -420,8 +421,7 @@ void EditClock::schedRules()
 
 void EditClock::svcData()
 {
-  EditPerms *dialog=new EditPerms(edit_name,EditPerms::ObjectClock,
-				  this,"dialog");
+  EditPerms *dialog=new EditPerms(edit_name,EditPerms::ObjectClock,this);
   dialog->exec();
   delete dialog;
 }
@@ -479,7 +479,7 @@ void EditClock::saveAsData()
   }
   delete q;
 
-  AddClock *addclock=new AddClock(&clockname,this,"addclock");
+  AddClock *addclock=new AddClock(&clockname,this);
   if(addclock->exec()<0) {
     delete addclock;
     return;
@@ -541,8 +541,7 @@ void EditClock::editEventData(int line)
   if(event==NULL) {
     return;
   }
-  EditEvent *dialog=new EditEvent(event->name(),false,&new_events,
-				  this,"dialog");
+  EditEvent *dialog=new EditEvent(event->name(),false,&new_events,this);
   if(dialog->exec()<-1) {
     delete dialog;
     return;
