@@ -307,7 +307,8 @@ void GenerateLog::createData()
   // Generate Log
   //
   RDSvc *svc=new RDSvc(gen_service_box->currentText(),this);
-  QString logname=RDDateDecode(svc->nameTemplate(),gen_date_edit->date());
+  QString logname=RDDateDecode(svc->nameTemplate(),gen_date_edit->date(),
+			       svc->name());
   RDLog *log=new RDLog(logname);
   if(log->exists()) {
     str1=QString(tr("The log for"));
@@ -361,9 +362,10 @@ void GenerateLog::createData()
   connect(svc,SIGNAL(generationProgress(int)),
 	  gen_progress_dialog,SLOT(setProgress(int)));
   svc->generateLog(gen_date_edit->date(),
-		   RDDateDecode(svc->nameTemplate(),gen_date_edit->date()),
+		   RDDateDecode(svc->nameTemplate(),gen_date_edit->date(),
+				svc->name()),
 		   RDDateDecode(svc->nameTemplate(),gen_date_edit->date().
-				addDays(1)),&unused_report);
+				addDays(1),svc->name()),&unused_report);
   log->updateTracks();
   delete log;
   delete svc;
@@ -392,7 +394,8 @@ void GenerateLog::musicData()
   unsigned tracks=0;
 
   RDSvc *svc=new RDSvc(gen_service_box->currentText(),this);
-  QString logname=RDDateDecode(svc->nameTemplate(),gen_date_edit->date());
+  QString logname=RDDateDecode(svc->nameTemplate(),gen_date_edit->date(),
+			       svc->name());
   RDLog *log=new RDLog(logname);
   if(((log->linkState(RDLog::SourceMusic)==RDLog::LinkDone)||
       (log->linkState(RDLog::SourceTraffic)==RDLog::LinkDone))) {
@@ -443,7 +446,8 @@ void GenerateLog::musicData()
 void GenerateLog::trafficData()
 {
   RDSvc *svc=new RDSvc(gen_service_box->currentText(),this);
-  QString logname=RDDateDecode(svc->nameTemplate(),gen_date_edit->date());
+  QString logname=RDDateDecode(svc->nameTemplate(),gen_date_edit->date(),
+			       svc->name());
   RDLog *log=new RDLog(logname);
   if((log->linkState(RDLog::SourceTraffic)==RDLog::LinkDone)) {
     QString str1=QString(tr("The log for"));
@@ -477,7 +481,8 @@ void GenerateLog::trafficData()
 void GenerateLog::fileScanData()
 {
   RDSvc *svc=new RDSvc(gen_service_box->currentText(),this);
-  QString logname=RDDateDecode(svc->nameTemplate(),gen_date_edit->date());
+  QString logname=RDDateDecode(svc->nameTemplate(),gen_date_edit->date(),
+			       svc->name());
   RDLog *log=new RDLog(logname);
   if(gen_music_enabled) {
     if(QFile::exists(svc->
@@ -545,7 +550,8 @@ void GenerateLog::resizeEvent(QResizeEvent *e)
 void GenerateLog::UpdateControls()
 {
   RDSvc *svc=new RDSvc(gen_service_box->currentText(),this);
-  QString logname=RDDateDecode(svc->nameTemplate(),gen_date_edit->date());
+  QString logname=RDDateDecode(svc->nameTemplate(),gen_date_edit->date(),
+			       svc->name());
   RDLog *log=new RDLog(logname);
   if(log->exists()) {
     if(log->linkQuantity(RDLog::SourceMusic)>0) {
