@@ -2,9 +2,7 @@
 //
 // Global Variable Declarations for RDPanel
 //
-//   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
-//
-//      $Id: globals.h,v 1.4 2007/02/14 21:57:04 fredg Exp $
+//   (C) Copyright 2002-2004,2016 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -28,15 +26,18 @@
 #include <rdaudio_port.h>
 #include <rduser.h>
 #include <rdripc.h>
+#include <rdcart_dialog.h>
 
 //
 // Global Resources
 //
 extern RDStation *rdstation_conf;
+extern RDSystem *rdsystem_conf;
 extern RDAirPlayConf *rdairplay_conf;
 extern RDAudioPort *rdaudioport_conf;
 extern RDUser *rduser;
 extern RDRipc *rdripc;
+extern RDCartDialog *panel_cart_dialog;
 
 
 #endif  // GLOBALS_H
