@@ -2,9 +2,7 @@
 //
 // Rivendell Interprocess Communication Daemon
 //
-//   (C) Copyright 2002-2003 Fred Gleason <fredg@paravelsystems.com>
-//
-//      $Id: ripcd_socket.cpp,v 1.6 2007/09/14 14:06:59 fredg Exp $
+//   (C) Copyright 2002-2003,2016 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -34,16 +32,15 @@
 
 #include <ripcd_socket.h>
 
-RipcdSocket::RipcdSocket(Q_UINT16 port,int backlog,QObject *parent,
-		     const char *name) 
-  : QServerSocket(port,0,parent,name)
+RipcdSocket::RipcdSocket(Q_UINT16 port,int backlog,QObject *parent)
+  : QServerSocket(port,0,parent)
 {
 }
 
 
 RipcdSocket::RipcdSocket(const QHostAddress &address,Q_UINT16 port,int backlog,
-			 QObject *parent,const char *name) 
-  : QServerSocket(address,port,0,parent,name)
+			 QObject *parent) 
+  : QServerSocket(address,port,0,parent)
 {
 }
 
