@@ -85,6 +85,7 @@ MainObject::MainObject(QObject *parent)
   //
   rev_config=new RDConfig();
   rev_config->load();
+  rev_config->setModuleName("rdrevert");
 
   //
   // Open Database
@@ -194,6 +195,42 @@ void MainObject::Revert(int schema) const
   case 259:
     Revert259();
     break;
+
+  case 260:
+    Revert260();
+    break;
+
+  case 261:
+    Revert261();
+    break;
+
+  case 262:
+    Revert262();
+    break;
+
+  case 263:
+    Revert263();
+    break;
+
+  case 264:
+    Revert264();
+    break;
+
+  case 265:
+    Revert265();
+    break;
+
+  case 266:
+    Revert266();
+    break;
+
+  case 267:
+    Revert267();
+    break;
+
+  case 268:
+    Revert268();
+    break;
   }
 }
 
@@ -529,6 +566,129 @@ void MainObject::Revert259() const
 }
 
 
+void MainObject::Revert260() const
+{
+  QString sql;
+  QSqlQuery *q;
+
+  sql=QString("alter table USERS drop column WEBAPI_AUTH_TIMEOUT");
+  q=new QSqlQuery(sql);
+  delete q;
+
+  sql=QString("drop table WEBAPI_AUTHS");
+  q=new QSqlQuery(sql);
+  delete q;
+
+  SetVersion(259);
+}
+
+
+void MainObject::Revert261() const
+{
+  QString sql;
+  QSqlQuery *q;
+
+  sql=QString("alter table CUTS drop column SHA1_HASH");
+  q=new QSqlQuery(sql);
+  delete q;
+
+  SetVersion(260);
+}
+
+
+void MainObject::Revert262() const
+{
+  QString sql;
+  QSqlQuery *q;
+
+  sql=QString("alter table USERS drop column LOCAL_AUTH");
+  q=new QSqlQuery(sql);
+  delete q;
+
+  sql=QString("alter table USERS drop column PAM_SERVICE");
+  q=new QSqlQuery(sql);
+  delete q;
+
+  sql=QString("drop index IPV4_ADDRESS_IDX on STATIONS");
+  q=new QSqlQuery(sql);
+  delete q;  
+
+  SetVersion(261);
+}
+
+
+void MainObject::Revert263() const
+{
+  // Nothing to do here as this is a pseudo-schema change.
+
+  SetVersion(262);
+}
+
+
+void MainObject::Revert264() const
+{
+  QString sql;
+  QSqlQuery *q;
+
+  sql="alter table SYSTEM drop column FIX_DUP_CART_TITLES";
+  q=new QSqlQuery(sql);
+  delete q;  
+
+  SetVersion(263);
+}
+
+
+void MainObject::Revert265() const
+{
+  QString sql;
+  QSqlQuery *q;
+
+  sql="alter table SYSTEM drop column SHOW_USER_LIST";
+  q=new QSqlQuery(sql);
+  delete q;  
+
+  SetVersion(264);
+}
+
+
+void MainObject::Revert266() const
+{
+  // Nothing to do here as this is a pseudo-schema change.
+
+  SetVersion(265);
+}
+
+
+void MainObject::Revert267() const
+{
+  QString sql;
+  QSqlQuery *q;
+
+  sql="alter table CUTS drop column ORIGIN_LOGIN_NAME";
+  q=new QSqlQuery(sql);
+  delete q;  
+
+  sql="alter table CUTS drop column SOURCE_HOSTNAME";
+  q=new QSqlQuery(sql);
+  delete q;  
+
+  SetVersion(266);
+}
+
+
+void MainObject::Revert268() const
+{
+  QString sql;
+  QSqlQuery *q;
+
+  sql="alter table DROPBOXES drop column FORCE_TO_MONO";
+  q=new QSqlQuery(sql);
+  delete q;  
+
+  SetVersion(267);
+}
+
+
 int MainObject::GetVersion() const
 {
   QString sql;
@@ -571,6 +731,8 @@ int MainObject::MapSchema(const QString &ver)
   version_map["2.13"]=255;
   version_map["2.14"]=258;
   version_map["2.15"]=259;
+  version_map["2.16"]=263;
+  version_map["2.17"]=268;
 
   //
   // Normalize String
